@@ -8,30 +8,34 @@ class PandasField(BaseField):
 
     def __set__(self, instance, value):
         if value is not None:
-            value = self.to_mongo(value)
+            value = self.to_python(value)
         super(PandasField, self).__set__(instance, value)
 
     def __get__(self, instance, owner):
         x = super(PandasField, self).__get__(instance, owner)
         if x is not None:
-            x = self.to_python(x)
+            x = self.to_mongo(x)
 
         return x
 
 
 class SeriesField(PandasField):
-    def to_mongo(self, value):
-        assert isinstance(value, pd.Series)
+    def to_python(self, value):
+        if isinstance(value, str):
+            return value
+        assert isinstance(value, pd.Series), "The type is {}".format(type(value))
         return value.to_json(orient="split")
 
-    def to_python(self, value):
+    def to_mongo(self, value):
         return pd.read_json(value, orient="split", typ="series")
 
 
 class FrameField(PandasField):
-    def to_mongo(self, value):
-        assert isinstance(value, pd.DataFrame)
+    def to_python(self, value):
+        if isinstance(value, str):
+            return value
+        assert isinstance(value, pd.DataFrame), "The type is {}".format(type(value))
         return value.to_json(orient="table")
 
-    def to_python(self, value):
+    def to_mongo(self, value):
         return pd.read_json(value, orient="table", typ="frame")
